---
title:  "New Connectivities and Environmental Activism: Examining the Role of Religious Groups with Social Network Analysis on Twitter"
abstract:    
style:  jeremy1
author: Jeremy H. Kidwell
affiliation: University of Edinburgh
e-mail: jeremy.kidwell@ed.ac.uk 
BibTeX: at-biblio_2015Aug07
linkcolor: black
fontsize: 11pt
...

There is something new happening with environmental activism. Whereas environmentalism in the latter half of the twentieth-century was characterised by a variety of fault lines generated by different forms of action whether radical, performative, policy-engaged, habitat-focussed, etc. each orientation drove different agendas such that groups often vied with one another as much as they did with the forces causing ecological devastation. One possible reason for the new turn towards alliances, collaborations, and more dynamic group identities is likely the way that the issue of climate change has captivated the global imagination. The astonishing range and urgency of climate change has drawn activists out from their traditional enclaves and this is shown in a range of new and highly diverse alliances which are emerging, such as "Stop Climate Chaos" in the United Kingdom, or the "Environmental Priorities Coalition" in the USA. In the light of these new forms of connectivity among activist groups, in this study I seek to analyse the digital space occupied by a specific (and often ignored) subset of environmental activists, namely religious groups. Through Social Network Analysis (SNA), I provide an assessment of the twitter traffic and engagement by religious sustainability and environmental groups within the larger constellation of conservation, environmental media, and government sustainability groups on national and international levels. SNA is a particularly well-suited tool for this kind of analysis, as it offers a way to transcend atomistic perspectives and grasp at the new mobilities and connectivities which characterise the work of these groups. As Wasserman and Faust suggest, SNA aims for a "unit of analysis" which is not the individual, "but an entity consisting of a collection of individuals and the linkages among them" {Wasserman 1994@5}. In seeking to better understand the significance and operations of Eco-Congregation Scotland (ECS) in research conducted from 2013-2016, we sought to deploy SNA towards a range of data and contexts, seeking to understand the environmental networks in which ECS operated and the smaller networks of which ECS was composed.

Before diving into the data and analysis, I would like to preface with some discussion of how environmental groups may be categorised. This will form the basis for some clusters which will help to illuminate some of the analysis which follows. We may begin by dividing environmental groups into two basic categories based on their political disposition. Seen in this way, our first cluster includes those groups which are located within the radical political tradition and which see positive environmental change as requiring a radical transformation or confrontation of the current political structures. Groups working in this mode may often take a confrontational stance, or see themselves as offering a counter-cultural alternative. The most obvious example of this mode of action may be represented by Earth First!, but it also includes groups like Greenpeace, the Greenpeace spin-off Friends of the Earth, or the student group People and Planet. The alternative mode is represented by those groups which seek to work within current political structures, and these groups are often actually quasi-governmental, receiving some or all of their funding from government. Groups which fit this category in Britain include "Keep Britain Tidy" (or the Scottish counterpart "Keep Scotland Beautiful" formerly named ENCAMS), or the Royal Society for the Protection of Birds. This second group is often focussed on good environmental citizenship, and as such prevents a more radical posture which might seek to oppose the structures of civil society which provide the basis for measuring good citizenship. Having laid out these two categories, it is important to note that both have become increasingly unstable over recent decades, with groups such as RSPB widening their focus to include things aside from birds, such as lobbying to change government policy and conversely with groups such as Greenpeace taking on more domestic concerns alongside their traditional focus on dramatic direct action. In both cases, some of the internal membership of these groups has resisted such reorientation, but it has nonetheless become the case that one cannot define an Environmental Non-Governmental Organisation (ENGO) along these lines in a strict sense. 

Whether or not they are strictly true, these two categories carry significant aesthetic freight for individuals seeking to participate in environmental action, and this is particularly the case for church groups in Britain seeking to participate in environmental action. In one concrete example of this phenomenon, I had an individual approach me after I had spoken at an event in a church in Edinburgh about the research being conducted for this project. The person waited until everyone in the room had gone and then said to me with a somewhat uneasy expression, "you know, my husband and I are both members of Greenpeace." Their presumption here was that a good church-goer was expected to avoid a radical group like Greenpeace. In my fieldwork, I have found evidence that this phenomena of uneasiness also exists in an inverse way. In one interview with an interfaith environmental group in the USA, a campaigner suggested to me "what we discovered as we became [active] into advocacy, [was that] at first the environmental community was very suspicious of us, very suspicious... and so they thought really that ... we were a trojan horse for creationism and they really didn't know how to deal with us."[^158261336] On both sides, misunderstanding and suspicion have prevented alliances from forming in the past, and yet now we see that these understandings are giving way – even if for strictly pragmatic reasons – to new coalitions which are providing more effective advocacy and organising. Understanding the ways in which religious environmental groups function will benefit from a deeper understanding of these dynamics with other environmental groups, and their place within these networks. It will also be useful to keep this uneasiness in mind when contrasting the levels of connectedness between religious ENGOs and other ENGOs with the levels of connection between religious ENGOs and other parallel religious groups such as denominational leadership and religious media. As I will go on to suggest, there is good reason to suspect that religious ENGOs offer a crucial point of connection to the broader environmental and conservation movement where almost no other forms of connection exist for religious communities to environmental politics.


## Analysis 1: Environmentalists on Twitter

From our first data collection pool, we created a social network graph based on twitter participation by religious groups and ENGOs in Britain (both faith-based and secular). For those readers who may not be familiar with SNA jargon, it may be helpful to note that social network analysis consists essentially of individual points (called "nodes" or "vertices") and the visual representation of connections between these points in the form of lines (called "edges"). For our visualisation, nodes were identified using a "snowball" technique, which resulted in a diverse selection of 82 vertices (or nodes). This included the starting point of 10 religious ENGOs (@ecocongregation @ArochaUK @ECenglandwales @JRayl @GreenChristian_ @ARCworld @ArthurRankCentr @OperationNoah @biggreenjewish @muslimness) and two staff members (@MiriamDobson @gordonhudsonu) as well as a selection of secular ENGOs (such as @rspbscotland @foescot @wwf_uk_politics), a small selection of twitter-active executives, government conservation groups (such as @naturalengland), development agencies involved in environmental advocacy (such as @oxfamgb), church twitter accounts (@c_of_e), and several forms of news media including faith/environment sections of mainstream media (@timesfaith @gdnbelief), church-oriented media (@churchtimes), and denominational publications (). The total data set included 17350 edges, and data was obtained and connections calculated using NodeXL software, which took the complete followers / following lists for each node and looked for mentions of these nodes within the most recent 200 tweets for each account. The richness of this dataset can be seen in the inclusion of media, government, secular and religious sources, including some possible sources (especially media) where one might expect to find functioning as a bridge between several sub-groups.

Twitter offers a useful focal point for this kind of analysis because following someone on twitter can often serve more as a symbolic action than a substantive one. It is often the case that active twitter users will have private "lists" which they use as a regular reading list in order to filter out a much larger pool of persons they follow. Consultants on social media engagement will often recommend that whenever someone chooses to "follow" that group on twitter they return the favour by following that person. In this way, following on twitter can serve as a context for offering both reciprocity and recognition. Of course, twitter engagement can be quite uneven, with some groups having begun nearly a decade ago and employing a full-time specialists in social media engagement as a form of outreach and recruiting (at the time of this writing on 28 March 2015 the first node to join twitter among those analysed, @greenpeaceuk, had 121,071 followers and 17,504 tweets whereas @birdlife_news, which was roughly in the middle with a start date of July 2009 nonetheless also had 37,388 followers and followed 5819 other twitter users), while for others twitter use is less robust or formally worked-out (@arochauk had only 418 followers and 298 tweets), nonetheless the picture that appears is surprisingly coherent.

*Table 1.1 Twitter Activity of Top-10 and Religious ENGO Vertices (See Appendix A for Full Data)*

ID | Vertex | Followed | Followers | Tweets | Favorites | Joined Twitter Date (UTC)
----|------|------|------|------|------|------|------|------|------
26 | oxfamgb | 8090 | 198176 | 24326 | 797 | 12-Aug-08
21 | natures_voice | 2422 | 148489 | 36250 | 1628 | 20-Jan-09
19 | greenpeaceuk | 4700 | 121071 | 17504 | 669 | 10-Apr-07
18 | wwf_uk | 3161 | 118890 | 15511 | 41931 | 29-Jan-09
37 | defragovuk | 656 | 76297 | 10953 | 129 | 23-Jun-09
8 | soilassociation | 2695 | 70557 | 19955 | 4149 | 6-Nov-08
58 | christian_aid | 8450 | 70101 | 17307 | 187 | 7-Jan-09
38 | naturalengland | 681 | 68480 | 8597 | 134 | 16-Sep-09
40 | wildlifetrusts | 361 | 55596 | 9706 | 5794 | 16-Jul-09
59 | c_of_e | 4378 | 47929 | 8890 | 249 | 3-Feb-09

34 | arcworld | 2649 | 2554 | 1489 | 120 | 17-Feb-09
12 | greenchristian_ | 1204 | 1361 | 4566 | 30 | 17-Feb-12
42 | cofecampaign | 839 | 1325 | 1628 | 11 | 9-Jun-10
31 | operationnoah | 386 | 795 | 908 | 45 | 18-Mar-09
44 | ecocongregation | 190 | 478 | 1543 | 1 | 16-Mar-09
53 | arthurrankcentr | 255 | 426 | 375 | 5 | 2-Mar-10
47 | arochauk | 64 | 418 | 298 | 98 | 24-Sep-13
57 | ecenglandwales | 260 | 295 | 565 | 20 | 24-Apr-13
68 | actscot | 222 | 121 | 95 | 257 | 13-Nov-14
84 | jrayl | 23 | 4 | 0 | 0 | 11-Apr-09

## 1. Bridges and Outliers
One of the key calculations that is relevant to this analysis is the *betweenness centrality*. This represents a calculation of the degree to which a specific actor lies on a path between two others, so nodes with a high calculation on this scale represent those which are not just more highly connected, but also act as a bridge between others who are unconnected. Betweenness represents perhaps the most dramatic relief for the religious ENGO in this study. In this analysis, the top three highest *between centrality* calculations were all religious ENGO's: with @greenchristian_ at 973.237, @operationnoah at 375.604 and @ecocongregation at 250.675. The average Betweenness Centrality was 63.171 and the median Betweenness Centrality was 28.53.

*Table 1.2 Top Vertices on Betweenness Centrality Graph Metrics*

ID | Vertex (Twitter @Handle)	|Betweenness Centrality
--------|:----------:	|:----------:
12 | greenchristian_ | 973.237
31 | operationnoah | 375.604
44 | ecocongregation | 250.675
58 | christian_aid | 224.759
19 | greenpeaceuk | 201.979
15 | christianaidsco | 181.776
17 | sccscot | 161.144
18 | wwf_uk | 154.77
62 | ctbi | 145.281
7 | peopleandplanet | 144.455
42 | cofecampaign | 142.963

53 | arthurrankcentr | 58.347
14 | biggreenjewish | 33.362
34 | arcworld | 32.505
57 | ecenglandwales | 22.307
47 | arochauk | 9.57
60 | muslimness | 0.179
84 | jrayl | 0

Sociologist Mark S. Granovetter highlighted the significance of this kind of networked configuration with his now famous 1973 paper on *The Strength of Weak Ties*. Granovetter took the common-sense the observation that "our acquaintances (weak ties) are less likely to be socially involved with one another than are our close friends (strong ties)" and noted that though the relationships with these weak ties are less strong and active, this makes them more important than our strong ties in one crucial way. In this way, "the weak tie... becomes not merely a trivial acquaintance tie but rather a crucial bridge between the two densely knit clumps of close friends... these clumps would not, in fact, be connected to one another at all were it not for the existence of weak ties." {Granovetter 1983@201-202}. Granovetter's suggestion fits this context, and applied here it seems fair to suggest that these religious ENGO's play a crucial role in connecting several networks (in this case the religious communities and environmental conservation NGOs) which would likely not be connected at all without this crucial bridge present.

[JK note: I'll add an additional section here running the same analysis again and showing map without any of the 10 ENGO's present to show the contrast]


## 2. Social Symmetries ##
A second calculation which is relevant to our inquiry is the degree of symmetry or asymmetry of communication. This relates essentially to reciprocation, and thus those who follow but aren't followed may represent a less overall relevant node within a network.

## Analysis 2: Sub-Group Connectivity, ECS Church Websites ##

## Analysis 3: Outwards Connections, ECS Application Forms ##



# Appendix a: Full Twitter Data #

ID | Vertex | Followed | Followers | Tweets | Favorites | Location | Web | Time Zone | Joined Twitter Date (UTC)
----|------|------|------|------|------|------|------|------|------
26 | oxfamgb | 8090 | 198176 | 24326 | 797 | Oxford, UK | http://t.co/qt7mRGgTtA | London | 12-Aug-08
21 | natures_voice | 2422 | 148489 | 36250 | 1628 | Sandy, UK | http://t.co/f1MFJqdZdL | London | 20-Jan-09
19 | greenpeaceuk | 4700 | 121071 | 17504 | 669 | UK | http://t.co/6wzJvB8Io1 |  | 10-Apr-07
18 | wwf_uk | 3161 | 118890 | 15511 | 41931 | Woking, UK | http://t.co/eVIp9uCMZ0 | London | 29-Jan-09
37 | defragovuk | 656 | 76297 | 10953 | 129 | UK | http://t.co/UqOuf07JUQ | London | 23-Jun-09
8 | soilassociation | 2695 | 70557 | 19955 | 4149 | The UK and beyond | http://t.co/WiiPQ6jdfH | London | 6-Nov-08
58 | christian_aid | 8450 | 70101 | 17307 | 187 |  | http://t.co/WpsPE6VE7Y | London | 7-Jan-09
38 | naturalengland | 681 | 68480 | 8597 | 134 | Sheffield, UK | https://t.co/vq6640bqBf | London | 16-Sep-09
40 | wildlifetrusts | 361 | 55596 | 9706 | 5794 | UK, Isle of Man and Alderney | http://t.co/UJsV3tRLpq | London | 16-Jul-09
59 | c_of_e | 4378 | 47929 | 8890 | 249 | London | http://t.co/bI6HwyysR5 | London | 3-Feb-09
35 | birdlife_news | 5819 | 37388 | 8267 | 2920 | Cambridge, UK | http://t.co/C2rEtLKhmJ | London | 15-Jul-09
71 | catholicherald | 261 | 34628 | 15404 | 84 |  | http://t.co/p5ERilFSSV | Amsterdam | 30-Dec-08
22 | 38_degrees | 7630 | 31692 | 9002 | 1237 | Millions across the UK | http://t.co/UXwPi3rH7q | London | 5-Mar-09
46 | _bct_ | 3164 | 24865 | 6697 | 1053 | Vauxhall, London | http://t.co/KGNJ15g9w8 | London | 18-Feb-09
23 | buzz_dont_tweet | 1770 | 21907 | 10826 | 561 | UK | http://t.co/DjTBLQqDxL | London | 21-Feb-11
69 | churchtimes | 656 | 19569 | 6541 | 46 |  | http://t.co/VfKkhZhpxe | London | 9-Feb-09
6 | transitiontowns | 2471 | 17386 | 11516 | 1343 | Everywhere | http://t.co/ESMCowqnTS | London | 22-Mar-09
24 | mcsuk | 1665 | 17213 | 9547 | 2321 | Ross-on-Wye, Herefordshire | http://t.co/S5B1OECh2a | London | 26-Jan-10
36 | scotwildlife | 836 | 16107 | 2502 | 91 | Edinburgh and Scotland | http://t.co/OhqrQAnstu | Edinburgh | 30-Nov-09
49 | love_plants | 2495 | 15595 | 5068 | 969 | UK | http://t.co/9vKQmQzpup | London | 6-Jan-11
72 | eauknews | 390 | 14924 | 7993 | 139 | London | http://t.co/bXUsxauv1h |  | 31-Mar-09
3 | robintransition | 1192 | 14642 | 13677 | 27 | Totnes, Devon. UK | https://t.co/IiDJgDMjTL |  | 7-May-09
70 | salvationarmyuk | 1144 | 14402 | 16614 | 2562 | UK & Ireland | http://t.co/RmI5Z892SH | London | 20-Feb-09
25 | frack_off | 847 | 14296 | 9654 | 60 |  | http://t.co/QY4muhnRtl | London | 23-Jun-11
7 | peopleandplanet | 3533 | 12779 | 16676 | 1764 | Oxford, UK | http://t.co/QZUY08hvqJ | London | 6-Jul-09
29 | cafod | 1320 | 11348 | 7230 | 1071 | England & Wales | http://t.co/2TkxCIXoep | London | 18-Dec-08
28 | rspbscotland | 1014 | 11058 | 5286 | 581 | Scotland | http://t.co/UMoQX2sVJn | Edinburgh | 31-May-11
79 | timesfaith | 10821 | 10040 | 1302 | 0 | The Times, London | http://t.co/awBBxsmnew | Amsterdam | 26-Aug-10
75 | gdnbelief | 145 | 8845 | 7838 | 1 | London | http://t.co/2F85Z5U47v | London | 9-Feb-11
66 | biblesociety | 268 | 8541 | 3674 | 61 | England and Wales | http://t.co/mmIb39thFF | London | 23-Feb-09
65 | methodistmedia | 6626 | 8180 | 7042 | 164 | London, UK | http://t.co/aPX2LkA4aH | Amsterdam | 28-May-09
20 | oxfamscotland | 757 | 7675 | 21897 | 12419 | Scotland | http://t.co/JVi6S7OTOI | Edinburgh | 10-May-09
48 | naturalscotland | 839 | 7466 | 3896 | 40 | in wild bits of Scotland |  | London | 31-Aug-09
30 | foescot | 1414 | 6741 | 10477 | 376 | Edinburgh, Scotland | http://t.co/0yxYojvRqM | Edinburgh | 17-Jul-09
39 | mscintheuk | 719 | 6444 | 2988 | 1194 | London, United Kingdom | http://t.co/ROww5FSxl9 |  | 18-Jun-12
52 | greenerscotland | 256 | 6094 | 4167 | 12 | Edinburgh | http://t.co/uq25vt8mxm | Edinburgh | 28-Jul-09
27 | wwf_uk_politics | 1811 | 5677 | 7884 | 31 | UK | http://t.co/Nwe7ltA4zK | London | 18-Sep-09
60 | muslimness | 2092 | 5559 | 8376 | 21 | England, UK | http://t.co/cH7e5llsz9 | London | 1-Jun-09
45 | churchscotland | 966 | 4559 | 3425 | 114 | Scotland | http://t.co/kHHa49Cuwi | London | 14-Jun-11
5 | ksbscotland | 1183 | 4463 | 3373 | 661 | Stirling, Scotland | http://t.co/RKK2rJTaKg | Edinburgh | 9-Jul-08
54 | ionacommunity | 214 | 4446 | 1321 | 6 | Isle of Iona | http://t.co/sLMaLpQbHq | Edinburgh | 4-Mar-09
33 | britishquakers | 200 | 4329 | 2404 | 67 | Great Britain | http://t.co/CHwNjl5SKp | London | 24-Feb-10
50 | wildaboutplants | 1807 | 4252 | 2064 | 597 | National | http://t.co/AaCpquWVML | Amsterdam | 14-Jul-10
16 | notarsands | 1948 | 4250 | 10566 | 124 | UK | http://t.co/MKwOhYdaP3 | London | 4-Mar-10
73 | cafodwire | 1808 | 3402 | 3573 | 126 | London | http://t.co/PmkWGboUbp | London | 4-Mar-09
9 | andy2atkins | 883 | 3177 | 3795 | 253 | London based.  Here and there | http://t.co/ZXJPieIlrA | London | 10-Oct-11
55 | fairtradenation | 235 | 2971 | 1783 | 470 | Glasgow, Scotland | http://t.co/0RFcErymHF | Edinburgh | 9-Feb-09
64 | methrecorder | 1888 | 2798 | 1069 | 5 | 122 Golden Lane, London EC1 | http://t.co/SmRUuVpwdc | London | 10-Aug-09
14 | biggreenjewish | 890 | 2622 | 2784 | 11 | London, UK | http://t.co/uxRlzQzJpi | London | 12-Nov-09
56 | sciaf | 571 | 2608 | 4922 | 727 | Glasgow | http://t.co/0vjG6F29QV | Edinburgh | 25-Jan-10
34 | arcworld | 2649 | 2554 | 1489 | 120 | UK | http://t.co/47IqF0gucv | London | 17-Feb-09
81 | baptisttimes | 320 | 2509 | 2282 | 19 | Didcot | http://t.co/AUmW6ijhYo |  | 27-Oct-09
63 | baptistuniongb | 349 | 2482 | 3401 | 32 |  |  | Amsterdam | 8-Jan-09
62 | ctbi | 1280 | 2411 | 4204 | 72 |  | http://t.co/GmMTtLJ4tX | London | 17-Feb-10
10 | fossilfree_uk | 1372 | 2163 | 2300 | 1057 | United Kingdom | http://t.co/xNjuJueZ7s |  | 12-Apr-13
51 | greener2gethr | 1740 | 2087 | 1727 | 397 | Scotland | http://t.co/6R1cf2KPWu |  | 12-Jan-12
67 | urcmedia | 1106 | 2070 | 1222 | 171 | United Kingdom | http://t.co/nU4QrIgGKt |  | 13-Jan-10
11 | ssnscotland | 766 | 1948 | 1776 | 152 | Stirling, Scotland | http://t.co/DqDW6L2u4i | Casablanca | 15-Jun-11
32 | richard_dixon | 419 | 1746 | 7683 | 7 | Edinburgh |  | Edinburgh | 3-Aug-11
4 | transitionunis | 645 | 1733 | 4567 | 4 | 60+ unis across the UK | http://t.co/g7b5UKjyWZ | London | 17-Jan-10
74 | cafodprayer | 619 | 1675 | 1468 | 44 |  | http://t.co/lgeBOwDdy4 | London | 14-Feb-11
41 | publicissues | 688 | 1487 | 4250 | 43 | London | http://t.co/rexYu857Fj | London | 25-Jan-10
12 | greenchristian_ | 1204 | 1361 | 4566 | 30 | UK | http://t.co/uGZ5l8Zwfm | Casablanca | 17-Feb-12
42 | cofecampaign | 839 | 1325 | 1628 | 11 | England | http://t.co/43X4UMdv3z | London | 9-Jun-10
17 | sccscot | 827 | 1213 | 1122 | 392 | Scotland | http://t.co/2BkvWQxs50 | Edinburgh | 17-Feb-14
80 | secsynod | 32 | 1021 | 351 | 0 | Scotland | http://t.co/EOJtRxhYty | Casablanca | 1-Jun-10
15 | christianaidsco | 830 | 1019 | 1114 | 83 | Scotland | http://t.co/NrMnYc2B8n | Edinburgh | 6-Feb-11
76 | cofslifeandwork | 67 | 847 | 1140 | 14 |  | http://t.co/xmZN81wSsN |  | 13-Jan-10
13 | miriamdobson | 705 | 817 | 6859 | 3998 | Edinburgh | http://t.co/an4WCkpJNz | Amsterdam | 27-Sep-12
31 | operationnoah | 386 | 795 | 908 | 45 | UK | http://t.co/i1KyueCGvP | London | 18-Mar-09
83 | fred_drummond | 934 | 763 | 141 | 0 |  |  |  | 2-Aug-11
77 | sicscotland | 635 | 748 | 454 | 257 | St Andrews University | http://t.co/pkJiSw7rkm |  | 24-Oct-13
61 | churchesengland | 98 | 500 | 7233 | 2 | England | http://t.co/ztJvULVt9I | Amsterdam | 12-Oct-12
44 | ecocongregation | 190 | 478 | 1543 | 1 | Edinburgh | http://t.co/iqePMedlFI | Edinburgh | 16-Mar-09
53 | arthurrankcentr | 255 | 426 | 375 | 5 | Stoneleigh Park, Warwickshire | http://t.co/G4BhoFs2AY | Casablanca | 2-Mar-10
47 | arochauk | 64 | 418 | 298 | 98 |  | http://t.co/7eJ0UcM9Lu |  | 24-Sep-13
57 | ecenglandwales | 260 | 295 | 565 | 20 |  | http://t.co/nuuasQ70PT | London | 24-Apr-13
68 | actscot | 222 | 121 | 95 | 257 | Alloa | http://t.co/bUnfLQUjog |  | 13-Nov-14
82 | theconvener | 94 | 121 | 140 | 0 | Glasgow | http://t.co/JxQw0dzhqF | Edinburgh | 12-Oct-09
78 | tsa_scotland | 201 | 119 | 337 | 0 | 12a Dryden Road, Loanhead EH20 | http://t.co/hLWqozoxxz | London | 22-Mar-10
43 | ffkirkscotland | 81 | 52 | 22 | 2 | Scotland | http://t.co/2rJQez5LlN | Casablanca | 15-Aug-13
84 | jrayl | 23 | 4 | 0 | 0 |  | http://t.co/rYnsST76n3 | Pacific Time (US & Canada) | 11-Apr-09


# Appendix B: Full Graph Metrics #


ID | Vertex (Twitter @Handle)	| In-Degree	| Out-Degree	|Betweenness Centrality	| Closeness Centrality	|
--------|  --------------------	|:----------:	|:----------:	|:----------:	|:----------:	|
3 | robintransition | 9 | 5 | 4.025 | 0.006
4 | transitionunis | 12 | 10 | 18.353 | 0.007
5 | ksbscotland | 13 | 22 | 64.384 | 0.007
6 | transitiontowns | 19 | 20 | 74.179 | 0.007
7 | peopleandplanet | 30 | 12 | 144.455 | 0.008
8 | soilassociation | 23 | 7 | 42.843 | 0.007
9 | andy2atkins | 21 | 27 | 117.878 | 0.008
10 | fossilfree_uk | 12 | 15 | 18.252 | 0.007
11 | ssnscotland | 13 | 24 | 58.311 | 0.007
12 | greenchristian_ | 19 | 58 | 973.237 | 0.01
13 | miriamdobson | 6 | 20 | 50.377 | 0.007
14 | biggreenjewish | 5 | 18 | 33.362 | 0.007
15 | christianaidsco | 19 | 29 | 181.776 | 0.008
16 | notarsands | 11 | 11 | 6.039 | 0.006
17 | sccscot | 22 | 32 | 161.144 | 0.008
18 | wwf_uk | 34 | 15 | 154.77 | 0.008
19 | greenpeaceuk | 33 | 12 | 201.979 | 0.008
20 | oxfamscotland | 17 | 10 | 31.969 | 0.007
21 | natures_voice | 27 | 15 | 69.186 | 0.008
22 | 38_degrees | 12 | 6 | 12.897 | 0.007
23 | buzz_dont_tweet | 18 | 21 | 24.035 | 0.007
24 | mcsuk | 17 | 21 | 26.22 | 0.007
25 | frack_off | 14 | 4 | 9.157 | 0.007
26 | oxfamgb | 26 | 5 | 126.571 | 0.008
27 | wwf_uk_politics | 15 | 15 | 48.283 | 0.007
28 | rspbscotland | 19 | 26 | 56.571 | 0.007
29 | cafod | 16 | 15 | 41.483 | 0.007
30 | foescot | 22 | 28 | 99.544 | 0.008
31 | operationnoah | 23 | 34 | 375.604 | 0.008
32 | richard_dixon | 16 | 11 | 16.602 | 0.006
33 | britishquakers | 13 | 13 | 29.595 | 0.007
34 | arcworld | 11 | 17 | 32.505 | 0.007
35 | birdlife_news | 12 | 7 | 7.401 | 0.007
36 | scotwildlife | 17 | 16 | 16.908 | 0.007
37 | defragovuk | 24 | 9 | 29.309 | 0.007
38 | naturalengland | 21 | 14 | 28.602 | 0.007
39 | mscintheuk | 12 | 9 | 5.801 | 0.007
40 | wildlifetrusts | 21 | 8 | 22.625 | 0.007
41 | publicissues | 13 | 18 | 24.635 | 0.007
42 | cofecampaign | 16 | 33 | 142.963 | 0.008
43 | ffkirkscotland | 4 | 6 | 1.7 | 0.006
44 | ecocongregation | 24 | 32 | 250.675 | 0.008
45 | churchscotland | 22 | 21 | 115.148 | 0.007
46 | _bct_ | 14 | 21 | 22.28 | 0.007
47 | arochauk | 7 | 12 | 9.57 | 0.007
48 | naturalscotland | 11 | 14 | 7.88 | 0.007
49 | love_plants | 18 | 14 | 28.457 | 0.007
50 | wildaboutplants | 10 | 22 | 17.465 | 0.007
51 | greener2gethr | 11 | 15 | 9.091 | 0.007
52 | greenerscotland | 17 | 14 | 37.626 | 0.007
53 | arthurrankcentr | 7 | 15 | 58.347 | 0.007
54 | ionacommunity | 15 | 10 | 41.144 | 0.007
55 | fairtradenation | 8 | 7 | 2.356 | 0.006
56 | sciaf | 15 | 15 | 52.83 | 0.007
57 | ecenglandwales | 7 | 17 | 22.307 | 0.007
58 | christian_aid | 37 | 15 | 224.759 | 0.008
59 | c_of_e | 30 | 10 | 84.382 | 0.008
60 | muslimness | 3 | 4 | 0.179 | 0.006
61 | churchesengland | 11 | 15 | 7.862 | 0.006
62 | ctbi | 26 | 36 | 145.281 | 0.008
63 | baptistuniongb | 14 | 14 | 11.615 | 0.007
64 | methrecorder | 9 | 15 | 11.623 | 0.007
65 | methodistmedia | 24 | 15 | 32.847 | 0.007
66 | biblesociety | 14 | 7 | 13.078 | 0.006
67 | urcmedia | 18 | 20 | 33.035 | 0.007
68 | actscot | 9 | 21 | 48.395 | 0.007
69 | churchtimes | 21 | 22 | 99.503 | 0.008
70 | salvationarmyuk | 14 | 14 | 36.584 | 0.007
71 | catholicherald | 14 | 3 | 12.752 | 0.007
72 | eauknews | 18 | 16 | 55.214 | 0.007
73 | cafodwire | 11 | 14 | 16.886 | 0.007
74 | cafodprayer | 6 | 10 | 3.781 | 0.006
75 | gdnbelief | 16 | 3 | 16.388 | 0.007
76 | cofslifeandwork | 13 | 13 | 17.08 | 0.006
77 | sicscotland | 7 | 11 | 9.557 | 0.006
78 | tsa_scotland | 7 | 18 | 19.974 | 0.006
79 | timesfaith | 8 | 2 | 1.919 | 0.006
80 | secsynod | 10 | 10 | 8.046 | 0.007
81 | baptisttimes | 11 | 9 | 2.686 | 0.006
82 | theconvener | 4 | 5 | 0.537 | 0.006
83 | fred_drummond | 9 | 8 | 5.329 | 0.006
84 | jrayl | 0 | 0 | 0 | 0


[^158261336]: Interview with Earth Ministry, 25 March 2015.